<big>Calculator</big>
=========================================

A simple UI calculator written in Tkinter.

This is a basic calculator supporting basic mathematic operations(addition, product, substraction and division).
The User Interface was made with Tkinter(a GUI binding distributed with the standard library of Python) and Python version 3.4
  
<big>Usage</big>
=========================================  
To launch the calculator application, just download the source code, and run the following command:  
```
python3 main.py
```
No dependencies are required to run the application, because all of them actually ship with the standard Python version 3 distributions.  

<big>Screenshots</big>
=========================================
Programming with Python and Tkinter made it possible for this application to be portable and cross-platform, works on Linux, Mac OS X and Windows.

<img src="http://i.imgur.com/P8egvrz.png" border="0" alt="Calculator Screenshot">
